--- loncom/interface/lonhtmlcommon.pm 2004/04/06 15:07:41 1.62
+++ loncom/interface/lonhtmlcommon.pm 2004/06/04 16:05:47 1.74
@@ -1,7 +1,7 @@
# The LearningOnline Network with CAPA
# a pile of common html routines
#
-# $Id: lonhtmlcommon.pm,v 1.62 2004/04/06 15:07:41 matthew Exp $
+# $Id: lonhtmlcommon.pm,v 1.74 2004/06/04 16:05:47 www Exp $
#
# Copyright Michigan State University Board of Trustees
#
@@ -163,9 +163,15 @@ sub textbox {
##############################################
##############################################
sub checkbox {
- my ($name,$value) = @_;
- my $Str = '';
+ my ($name,$checked,$value) = @_;
+ my $Str = '\n";
+ # Month
my @Months = qw/January February March April May June
July August September October November December/;
# Pad @Months with a bogus value to make indexing easier
@@ -316,39 +327,47 @@ ENDJS
$result .= "> ".&mt($Months[$m])." \n";
}
$result .= " \n";
+ # Day
$result .= " \n";
+ # Year
$result .= " \n";
$result .= " ";
- $result .= " \n";
- $result .= " m\n";
- $result .= " s\n";
+ if (! $no_hh_mm_ss) {
+ # Hours
+ $result .= " \n";
+ $result .= " m\n";
+ $result .= " s\n";
+ }
$result .= "".
&mt('Select Date')."\n\n";
return $result;
@@ -392,18 +411,26 @@ sub get_date_from_form {
if (($tmpsec =~ /^\d+$/) && ($tmpsec >= 0) && ($tmpsec < 60)) {
$sec = $tmpsec;
}
+ if (!defined($tmpsec) || $tmpsec eq '') { $sec = 0; }
+ } else {
+ $sec = 0;
}
if (defined($ENV{'form.'.$dname.'_minute'})) {
my $tmpmin = $ENV{'form.'.$dname.'_minute'};
if (($tmpmin =~ /^\d+$/) && ($tmpmin >= 0) && ($tmpmin < 60)) {
$min = $tmpmin;
}
+ if (!defined($tmpmin) || $tmpmin eq '') { $min = 0; }
+ } else {
+ $min = 0;
}
if (defined($ENV{'form.'.$dname.'_hour'})) {
my $tmphour = $ENV{'form.'.$dname.'_hour'};
if (($tmphour =~ /^\d+$/) && ($tmphour >= 0) && ($tmphour < 24)) {
$hour = $tmphour;
}
+ } else {
+ $hour = 0;
}
if (defined($ENV{'form.'.$dname.'_day'})) {
my $tmpday = $ENV{'form.'.$dname.'_day'};
@@ -841,37 +868,73 @@ sub crumbs {
# ------------------------------------------------- Output headers for HTMLArea
sub htmlareaheaders {
- unless (&htmlareablocked()) { return ''; }
+ if (&htmlareablocked()) { return ''; }
my $lang='en';
+ if (&mt('htmlarea_lang') ne 'htmlarea_lang') {
+ $lang=&mt('htmlarea_lang');
+ }
return (<
- _editor_url="/htmlarea/";
+_editor_url='/htmlarea/';
+_editor_lang='$lang';
-
-
-
ENDHEADERS
}
+# ------------------------------------------------- Activate additional buttons
+
+sub htmlareaaddbuttons {
+ if (&htmlareablocked()) { return ''; }
+ return (<\$','\$');
+ }
+ );
+ config.registerButton('ed_math_eqn','LaTeX Equation',
+ '/htmlarea/images/ed_math_eqn.gif',false,
+ function(editor,id) {
+ editor.surroundHTML('
\\\\[','\\\\]
');
+ }
+ );
+ config.toolbar.push(['ed_math','ed_math_eqn']);
+ENDADDBUTTON
+}
# ---------------------------------------------------------- Script to activate
sub htmlareaactive {
- unless (&htmlareablocked()) { return ''; }
+ if (&htmlareablocked()) { return ''; }
+ my $addbuttons=&htmlareaaddbuttons();
return (<
- HTMLArea.replaceAll();
+ $addbuttons
+ HTMLArea.replaceAll(config);
ENDSCRIPT
}
+# ----------------------------------------- Script to activate only some fields
+
+sub htmlareaselectactive {
+ my @fields=@_;
+ if (&htmlareablocked()) { return ''; }
+ my $output='";
+ return $output;
+}
+
# --------------------------------------------------------------------- Blocked
sub htmlareablocked {
- unless (&htmlareabrowser()) { return ''; }
- return 1;
+ unless (&htmlareabrowser()) { return 1; }
+ return 0;
}
# ---------------------------------------- Browser capable of running HTMLArea?
@@ -899,6 +962,9 @@ All inputs can be undef without problems
Inputs: $color (the background color of the table returned),
$component (the large text on the right side of the table),
$component_help
+ $function (role to get colors from)
+ $domain (domian of role)
+ $menulink (boolean, controls whether to include a link to /adm/menu)
Returns a string containing breadcrumbs for the current page.
@@ -924,7 +990,8 @@ returns: nothing
my @Crumbs;
sub breadcrumbs {
- my ($color,$component,$component_help,$function,$domain) = @_;
+ my ($color,$component,$component_help,$function,$domain,$menulink) =
+ @_;
if (! defined($color)) {
if (! defined($function)) {
$function = &Apache::loncommon::get_users_function();
@@ -944,22 +1011,34 @@ returns: nothing
# The last breadcrumb does not have a link, so handle it separately.
my $last = pop(@Crumbs);
#
- # The first one should be the course, I guess.
- if (exists($ENV{'request.course.id'})) {
- my $cid = $ENV{'request.course.id'};
+ # The first one should be the course or a menu link
+ if (!defined($menulink)) { $menulink=1; }
+ if ($menulink) {
+ my $description = 'Menu';
+ if (exists($ENV{'request.course.id'}) &&
+ $ENV{'request.course.id'} ne '') {
+ $description =
+ $ENV{'course.'.$ENV{'request.course.id'}.'.description'};
+ }
unshift(@Crumbs,{
- href=>'/adm/menu',
- title=>'Go to main menu',
- text=>$ENV{'course.'.$cid.'.description'},
- });
+ href =>'/adm/menu',
+ title =>'Go to main menu',
+ target =>'_top',
+ text =>$description,
+ });
}
my $links .=
join('->',
map {
$faq = $_->{'faq'} if (exists($_->{'faq'}));
$bug = $_->{'bug'} if (exists($_->{'bug'}));
- ''.
- &mt($_->{'text'}).''
+ my $result = '{'target'}) && $_->{'target'} ne '') {
+ $result .= 'target="'.$_->{'target'}.'" ';
+ }
+ $result .='title="'.&mt($_->{'title'}).'">'.
+ &mt($_->{'text'}).'';
+ $result;
} @Crumbs
);
$links .= '->' if ($links ne '');